<?php
/**
 * @author Colinet Julien
 */

namespace CpCreation\VitiCore\SocialNetwork\Model\Network;


class FacebookFacebook
{
    /**
     * @var string
     */
    private $id;

    /**
     * @var string
     */
    private $name;


    /**
     * @var string
     */
    private $accountFacebook;

    /**
     * @return string
     */
    public function getId(): ?string
    {
        return $this->id;
    }

    /**
     * @param string $id
     */
    public function setId(?string $id): void
    {
        $this->id = $id;
    }

    /**
     * @return string
     */
    public function getName(): ?string
    {
        return $this->name;
    }

    /**
     * @param string $name
     */
    public function setName(?string $name): void
    {
        $this->name = $name;
    }

    /**
     * @return string
     */
    public function getAccountFacebook(): ?string
    {
        return $this->accountFacebook;
    }

    /**
     * @param string $accountFacebook
     */
    public function setAccountFacebook(?string $accountFacebook): void
    {
        $this->accountFacebook = $accountFacebook;
    }

}