<?php
/**
 * @author Colinet Julien
 */

namespace CpCreation\VitiCore\Behavior;

interface HasGeocoder
{
    /**
     * @return string
     */
    public function getAddress(): ?string;

    /**
     * @param string $address
     */
    public function setAddress(?string $address);

    /**
     * @return string
     */
    public function getPostal(): ?string;

    /**
     * @param string $postal
     */
    public function setPostal(?string $postal);

    /**
     * @return string
     */
    public function getCity(): ?string;

    /**
     * @param string $city
     */
    public function setCity(?string $city);

    /**
     * @return string
     */
    public function getCountry(): ?string;

    /**
     * @param string $country
     */
    public function setCountry(string $country = null);

    /**
     * @return string
     */
    public function getLat(): ?string ;

    /**
     * @param string $lat
     */
    public function setLat(string $lat = null);

    /**
     * @return string
     */
    public function getLng(): ?string;

    /**
     * @param string $lng
     */
    public function setLng(string $lng = null);
}