<?php
/**
 * @author Colinet Julien
 */

namespace CpCreation\VitiCore\Bridge\Symfony\Bundle\Provider\Payment;

use CpCreation\VitiCore\Behavior\HasPayment;
use CpCreation\VitiCore\Contact\Model\Contact;

interface PaymentProviderInterface
{
    public function checkout(Contact $contact, HasPayment $payment);

    public function getMethod() :string;
}
