<?php
/**
 * @author Colinet Julien
 */

namespace CpCreation\VitiCore\Cart\Model\Payment;


use Symfony\Component\Validator\Constraints as Assert;

class Sherlock
{
    /**
     * @Assert\NotBlank()
     *
     * @var string
     */
    private $name;

    /**
     * @var boolean
     */
    private $debug;

    /**
     * @Assert\NotBlank()
     *
     * @var string
     */
    private $certif;

    /**
     * @return string
     */
    public function getName(): ?string
    {
        return $this->name;
    }

    /**
     * @param string $name
     */
    public function setName(?string $name): void
    {
        $this->name = $name;
    }

    /**
     * @return bool
     */
    public function getDebug(): ?bool
    {
        return $this->debug;
    }

    /**
     * @param bool $debug
     */
    public function setDebug(?bool $debug): void
    {
        $this->debug = $debug;
    }

    /**
     * @return string
     */
    public function getCertif(): ?string
    {
        return $this->certif;
    }

    /**
     * @param string $certif
     */
    public function setCertif(?string $certif): void
    {
        $this->certif = $certif;
    }
}
