<?php
/**
 * @author Colinet Julien
 */

namespace CpCreation\VitiCore\Bridge\Doctrine\Hydrator;

use Doctrine\ORM\Internal\Hydration\ObjectHydrator;

class PriceVariantHydrator extends ObjectHydrator
{
    protected function hydrateAllData()
    {
        $result = [];

        while ($row = $this->_stmt->fetch(\PDO::FETCH_ASSOC)) {
            $this->hydrateRowData($row, $result);
        }

        return $result;
    }
}