<?php
/**
 * @author Colinet Julien
 */

namespace CpCreation\VitiCore\Behavior;

use Doctrine\Common\Collections\Collection;

interface HasFiles
{
    /**
     * @return Collection<CpCreation\VitiCore\Media\Model\File>
     */
    public function getFiles(): Collection;
}