<?php
/**
 * @author Colinet Julien
 */

namespace CpCreation\VitiCore\Bridge\Symfony\Bundle\Provider\Carrier;

use CpCreation\VitiCore\Shop\Model\ShippingConfig;

interface CarrierProviderInterface
{
    public function setData(ShippingConfig $config);

    public function getCarrier() :string;
}
