<?php
/**
 * @author Colinet Julien
 */

namespace CpCreation\VitiCore\Behavior;

use CpCreation\VitiCore\Media\Model\File;

interface HasFile
{
    /**
     * @return File
     */
    public function getFile(): ?File;

    /**
     * @param File $file
     * @return mixed
     */
    public function setFile(File $file = null);
}
