{% extends '@CpCreationVitiCore/admin/base.html.twig' %}

{% block content %}
    <div class="panel panel-default">
        <div class="panel-heading">
            Produits
            {% if is_granted('ROLE_ADMIN') %}
                <div class="btn-group">
                    <a href="{{ path('admin_product_init_position_shop') }}" type="button" class="btn btn-default btn-xs btn-warning">
                        Réinitialiser position Shop
                    </a>
                    <a href="{{ path('admin_product_init_position') }}" type="button" class="btn btn-default btn-xs btn-warning">
                        Réinitialiser position Cuvées
                    </a>
                </div>
                <div class="pull-right">

                        <a href="{{ path('admin_product_new') }}" type="button" class="btn btn-default btn-xs">
                            Ajouter
                        </a>

                    </div>
                </div>
            {% endif %}
        </div>
        <table class="table table-bordered dataTable" width="100%" cellspacing="0">
            <thead>
            <tr>
                <th>#</th>
                <th></th>
                <th>Nom</th>
                <th>Qualité</th>
                <th>Catégorie</th>
                <th>Cuvées</th>
                <th>Shop</th>
                <th>Groupes</th>
                <th>Variant</th>
                <th>Position Cuvées</th>
                <th>Position Shop</th>
                <th>Action</th>
            </tr>
            </thead>
            <tfoot>
            <tr>
                <th>#</th>
                <th></th>
                <th>Nom</th>
                <th>Qualité</th>
                <th>Catégorie</th>
                <th>Cuvées</th>
                <th>Shop</th>
                <th>Groupes</th>
                <th>Variant</th>
                <th>Position Cuvées</th>
                <th>Position Shop</th>
                <th>Action</th>
            </tr>
            </tfoot>
            <tbody>

            {% for item in items %}
                <tr {% if item.disabled == 1 %} class="danger" {% endif %}>
                    <td>{{ loop.index }}</td>
                    <td> {% if item.image is not null %}
                            <img src="{{ asset(item.image.path) | imagine_filter('relative_widen_20_filter') }}"/>
                        {% endif %}
                    </td>
                    <td>{{ item.name }}</td>
                    <td> {% if item.quality %}{{ item.quality }}{% endif %}</td>
                    <td>
                        {% if item.category %}
                            {{ item.category.name }}
                        {% endif %}
                    </td>
                    <td>
                        {% if item.cuvee %}
                            <i class="fas fa-circle fa-2x color_green"></i>
                        {% else %}
                            <i class="fas fa-circle fa-2x color_red"></i>
                        {% endif %}
                    </td>
                    <td>
                        {% if item.shop %}
                            <i class="fas fa-circle fa-2x color_green"></i>
                        {% else %}
                            <i class="fas fa-circle fa-2x color_red"></i>
                        {% endif %}
                    </td>
                    <td>
                        {% for group in item.groups %}
                            <span class="label label-default">{{ group.name }}</span>
                        {% endfor %}
                    </td>
                    <td>
                        <ul class="list-unstyled">
                            {% for variant in item.variants %}
                                {% if variant.unPublished %}
                                    <li><s>{{ variant.type.name }}</s></li>
                                {% else %}
                                    <li>{{ variant.type.name }} {% if variant.type.info %}({{ variant.type.info }}){% endif %}</li>
                                {% endif %}
                            {% endfor %}
                        </ul>
                    </td>
                    <td>
                        {{ item.position}}
                        {% if loop.first == false %}
                            <a href="{{ path('admin_product_move_up', {id : item.id}) }}"
                               class="btn btn-default btn-xs" data-toggle="tooltip" title="Remonter le produit"><i
                                        class="fa fa-2x fa-arrow-up" aria-hidden="true"></i></a>
                        {% endif %}
                        {% if loop.last == false %}
                            <a href="{{ path('admin_product_move_down', {id : item.id}) }}"
                               class=" btn btn-default btn-xs" data-toggle="tooltip" title="Descendre le produit"><i
                                        class="fa fa-2x fa-arrow-down" aria-hidden="true"></i></a>
                        {% endif %}
                    </td>
                    <td>
                       {{ item.positionShop}}
                            <a href="{{ path('admin_product_move_up_shop', {id : item.id}) }}"
                               class="btn btn-default btn-xs" data-toggle="tooltip" title="Remonter le produit"><i
                                        class="fa fa-2x fa-arrow-up" aria-hidden="true"></i></a>

                            <a href="{{ path('admin_product_move_down_shop', {id : item.id}) }}"
                               class=" btn btn-default btn-xs" data-toggle="tooltip" title="Descendre le produit"><i
                                        class="fa fa-2x fa-arrow-down" aria-hidden="true"></i></a>

                    </td>
                    <td>
                        <a href="{{ path('admin_product_edit', { id: item.id}) }}" class="btn btn-info btn-xs"
                           data-toggle="tooltip" title="Editer le produit"><i class="fas fa-edit fa-2x"></i></a>
                        {% if is_granted('ROLE_ADMIN') %}
                            <a href="{{ path('admin_product_delete', { id: item.id }) }}"
                               class="confirm-deletable btn btn-danger btn-xs"
                               data-toggle="tooltip" title="Supprimer le produit {{ item.name }}"
                               data-title="Supprimer le produit {{ item.name }}">
                                <i class="fa fa-2x fa-trash"></i></a>
                        {% endif %}
                        {% if item.disabled == 0 %}
                            <a href="{{ path('admin_product_disable', { id: item.id }) }}"
                               class=" btn btn-default btn-xs" data-toggle="tooltip"
                               title="Dépublier le produit {{ item.name }}"><i
                                        class="fas fa-circle fa-2x color_green"></i></a>
                        {% else %}
                            <a href="{{ path('admin_product_enable', { id: item.id }) }}"
                               class=" btn btn-default btn-xs" data-toggle="tooltip"
                               title="Publier le produit {{ item.name }}"><i class="fas fa-circle fa-2x color_red"></i></a>
                        {% endif %}
                    </td>
                </tr>
            {% endfor %}
            </tbody>
        </table>
    </div>
{% endblock %}
