<?php
/**
 * @author Colinet Julien
 */

namespace CpCreation\VitiCore\Behavior;

use CpCreation\VitiCore\Media\Model\Video;

interface HasVideo
{
    /**
     * @return Video
     */
    public function getVideo(): ?Video;

    /**
     * @param Video $video
     * @return mixed
     */
    public function setVideo(Video $video = null);
}
