<?php
/**
 * @author Colinet Julien
 */

namespace CpCreation\VitiCore\Behavior;

use CpCreation\VitiCore\Media\Model\Image;

interface HasImage
{
    /**
     * @return Image
     */
    public function getImage(): ?Image;

    /**
     * @param Image $image
     */

    public function setImage(Image $image = null);
}
