<?php

namespace CpCreation\VitiCore\User\Repository;

use CpCreation\VitiCore\Repository\BaseRepository;
use CpCreation\VitiCore\User\Model\User;
use Doctrine\Persistence\ManagerRegistry;

class UserRepository extends BaseRepository
{
    /**
     * UserRepository constructor.
     * @param ManagerRegistry $registry
     * @throws \ReflectionException
     */
    public function __construct(ManagerRegistry $registry)
    {
        parent::__construct($registry, User::class);
    }

}