<?php
/**
 * @author Colinet Julien
 */

namespace CpCreation\VitiCore\Behavior;

use Doctrine\Common\Collections\Collection;

interface HasImages
{
    /**
     * @return Collection<CpCreation\VitiCore\Media\Model\Image>
     */
    public function getImages(): Collection;
}