<?php
/**
 * @author Colinet Julien
 */

namespace CpCreation\VitiCore\Bridge\Symfony\Bundle\Filesystem;

use League\Flysystem\Filesystem;

class GiftFilesystem extends Filesystem
{
    public function __construct(Filesystem $adapter, $config = null)
    {
        parent::__construct($adapter->getAdapter(),$config);
    }
}