<?php
/**
 * @author Colinet Julien
 */

namespace CpCreation\VitiCore\Bridge\Symfony\Bundle\Provider\SocialNetwork;

interface SocialNetworkProviderInterface
{
    public function getMedias($count);

    public function getNetwork() :string;
}
