{% spaceless %}
    {% if not form.vars.valid %}
        <div class="alert alert-danger alert-dismissible" role="alert">
            <h5>Les erreurs a corriger !</h5>
            {% if not form.vars.valid %}
                <ul class="list-error">
                    {% for error in form.vars.errors %}
                        <span class="title-error">{{ (error.origin.config.name)|trans([]) }}</span>
                        <li>{{ error.message }}</li>
                    {% endfor %}
                </ul>
            {% endif %}
            {% for children in form.children %}
                {% if not children.vars.valid %}
                    <span class="title-error"> {{ (children.vars.name)|trans([]) }}</span>
                    <ul>
                        {% for error in children.vars.errors.form.getErrors(true) %}
                            <li>{{ error.message }}</li>
                        {% endfor %}
                    </ul>
                {% endif %}
            {% endfor %}
        </div>
    {% endif %}
{% endspaceless %}
<div class="row">
    <div class="col-sm-12">
        {{ form_row(form.types) }}
    </div>
</div>
<div class="row">
    <div class="col-sm-4">
        {{ form_row(form.qtyOf) }}
        {{ form_row(form.qtyAt) }}
    </div>
    <div class="col-sm-4">
        {{ form_row(form.packagePrice) }}
        {{ form_row(form.bottlePrice) }}
    </div>
    <div class="col-sm-4">
        {{ form_row(form.packagePercent) }}
        {{ form_row(form.qtyOfBottleOffered) }}
        {{ form_row(form.mostOrderBottleInCart) }}
    </div>
</div>
<div class="row">
    <div class="panel panel-info">
        <div class="panel-heading">
            Groupes & Produits
        </div>
        <div class="panel-body">
            <div class="row">
                <div class="col-md-12"> {{ form_row(form.products) }}</div>
                <div class="col-md-12"> {{ form_row(form.groups) }}</div>
            </div>
        </div>
    </div>
</div>
<div class="row">
    <div class="panel panel-info">
        <div class="panel-heading">
            Calcul
        </div>
        <div class="panel-body">
            <div class="row">
                <div class="col-md-12"> {{ form_row(form.allQuantity) }}</div>
                <div class="col-md-12"> {{ form_row(form.equivalency) }}</div>
            </div>
        </div>
    </div>
</div>
{{ form_rest(form) }}
<div class="panel panel-default">
    <div class="panel-heading">
        Bouteille offerte à partir d'une certaine quantité de commande
    </div>
    <div class="panel-body">
        <p>La dégressivité par bouteille offerte permet d'offrir en remise tarifaire la bouteille la moins chère
            commandée lorsqu'une certaine quantité est atteinte. Cette quantité doit correspondre à la quantité a
            indiquer dans Qtyof(De) du formulaire. ( Si 1 bouteille offert à partir de 12, indiquer 11 dans QtyOf(De)</p>
        <p>Le qtyAt (A) est la valeur maximum de bouteille sur laquelle la dégressivité s'applique .</p>
        <p> Par exemple : <br/>
            Si nous avons une degressivité qui indique, 1 bouteille offerte à partir de 12 bouteilles jusque "infini", nous
            indiquerons :<br/>
            qtyOf: 11, qtyAt: 100000 et bouteille offerte : 1 <br/>
            A partir de 12 bouteilles, cela offira en remise tarifaire en prenant en compte le tarif de la bouteille la mpoins chère commandée. Ensuite chaque multiple de 12, cela viendrait ajouter une bouteille offerte supplémentaire.
        </p>
    </div>
</div>
