<?php
/**
 * @author Colinet Julien
 */

namespace CpCreation\VitiCore\Cart\Model\Payment;

class Etransactions
{
    /**
     * @var string
     */
    private $name;

    /**
     * @var bool
     */
    private $production;

    /**
     * @var string
     */
    private $site;

    /**
     * @var string
     */
    private $rank;

    /**
     * @var string
     */
    private $login;

    /**
     * @var string
     */
    private $hmacAlgo;

    /**
     * @var string
     */
    private $hmacKey;

    /**
     * @return string
     */
    public function getName(): ?string
    {
        return $this->name;
    }

    /**
     * @param string $name
     */
    public function setName(string $name): void
    {
        $this->name = $name;
    }

    /**
     * @return bool
     */
    public function isProduction(): ?bool
    {
        return $this->production;
    }

    /**
     * @param bool $production
     */
    public function setProduction(bool $production): void
    {
        $this->production = $production;
    }

    /**
     * @return mixed
     */
    public function getSite(): ?string
    {
        return $this->site;
    }

    /**
     * @param mixed $site
     */
    public function setSite($site): void
    {
        $this->site = $site;
    }

    /**
     * @return mixed
     */
    public function getRank(): ?string
    {
        return $this->rank;
    }

    /**
     * @param mixed $rank
     */
    public function setRank($rank): void
    {
        $this->rank = $rank;
    }

    /**
     * @return mixed
     */
    public function getLogin(): ?string
    {
        return $this->login;
    }

    /**
     * @param mixed $login
     */
    public function setLogin($login): void
    {
        $this->login = $login;
    }

    /**
     * @return mixed
     */
    public function getHmacAlgo(): ?string
    {
        return $this->hmacAlgo;
    }

    /**
     * @param mixed $hmacAlgo
     */
    public function setHmacAlgo($hmacAlgo): void
    {
        $this->hmacAlgo = $hmacAlgo;
    }

    /**
     * @return mixed
     */
    public function getHmacKey(): ?string
    {
        return $this->hmacKey;
    }

    /**
     * @param mixed $hmacKey
     */
    public function setHmacKey($hmacKey): void
    {
        $this->hmacKey = $hmacKey;
    }
}