{% if cart.cartCheckout.colissimoCarrier %}
    {% if cart.cartCheckout.colissimoCode %}
        {{ 'delivery.mail.colissimo_with_code'|trans({'%company%': company,'%ref%': cart.token,'%code%': cart.cartCheckout.colissimoCode }, null, cart.cartCheckout.locale )|nl2br|raw}}
    {% else %}
        {{ 'delivery.mail.colissimo'|trans({'%company%': company,'%ref%': cart.token }, null, cart.cartCheckout.locale )|nl2br|raw }}
    {% endif %}
{% else %}
    {{ 'delivery.mail.private'|trans({'%company%': company,'%ref%': cart.token }, null, cart.cartCheckout.locale )|nl2br|raw }}
{% endif %}
