{% if app.session.get('groupByDefault') == false %}
    <div class="active-code-price">
        <h5>{% trans with {'%code%': app.session.get('codePrice')|convert_id_to_name } %}shop.view_partner_price{% endtrans %} <a href="{{ path('price_code_delete') }}" title="{% trans %}shop.reset_partner_code{% endtrans %}">{% trans %}shop.reset{% endtrans %}</a></h5>
    </div>
{% else %}
    <form id="codePriceForm" action="{{ path('price_code') }}" method="post">
        <div class="grid-x">
            <h5 class="text-center">{% trans %}shop.partner_area{% endtrans %}</h5>
        </div>
        <div class="grid-x grid-margin-x grid-margin-y">
            <div class="cell input-code">
                {{ form_row(form.code) }}
                {{ form_rest(form) }}
                <button type="submit" class="button">{% trans %}shop.partner_valid{% endtrans %}</button>
            </div>
        </div>
    </form>
{% endif %}

