<?php
/**
 * @author Colinet Julien
 */
namespace CpCreation\VitiCore\Bridge\Symfony\Bundle\Validator\Constraints;

use Symfony\Component\Validator\Constraint;

/**
 * @Annotation
 */
class Translation extends Constraint
{
    public $message = 'Vous devez entrer certaines valeurs pour la langue {{ string }}';

    public function validatedBy()
    {
        return \get_class($this).'Validator';
    }

}