<?php

declare(strict_types=1);

namespace CpCreation\VitiCore\Bridge\Doctrine\Migrations;

use Doctrine\DBAL\Schema\Schema;
use Doctrine\Migrations\AbstractMigration;

/**
 * Auto-generated Migration: Please modify to your needs!
 */
final class Version20221103154122 extends AbstractMigration
{
    public function getDescription(): string
    {
        return '';
    }

    public function up(Schema $schema): void
    {
        // this up() migration is auto-generated, please modify it to your needs
        $this->addSql('ALTER TABLE award_award CHANGE image_id image_id CHAR(36) DEFAULT NULL COMMENT \'(DC2Type:uuid)\'');
        $this->addSql('ALTER TABLE award_award_translation CHANGE translatable_id translatable_id CHAR(36) DEFAULT NULL COMMENT \'(DC2Type:uuid)\'');
        $this->addSql('ALTER TABLE cart_cart CHANGE delivery_method_id delivery_method_id CHAR(36) DEFAULT NULL COMMENT \'(DC2Type:uuid)\', CHANGE invoice_address_id invoice_address_id CHAR(36) DEFAULT NULL COMMENT \'(DC2Type:uuid)\', CHANGE delivery_address_id delivery_address_id CHAR(36) DEFAULT NULL COMMENT \'(DC2Type:uuid)\', CHANGE shipping_name shipping_name VARCHAR(255) DEFAULT NULL, CHANGE group_code group_code VARCHAR(255) DEFAULT NULL, CHANGE delivery_method_json delivery_method_json JSON DEFAULT NULL, CHANGE promo promo VARCHAR(255) DEFAULT NULL, CHANGE promo_id promo_id CHAR(36) DEFAULT NULL COMMENT \'(DC2Type:uuid)\', CHANGE promo_value_percent promo_value_percent NUMERIC(3, 2) DEFAULT NULL, CHANGE tax tax NUMERIC(3, 2) DEFAULT NULL');
        $this->addSql('ALTER TABLE cart_cart_checkout CHANGE payment_method_id payment_method_id CHAR(36) DEFAULT NULL COMMENT \'(DC2Type:uuid)\', CHANGE cart_cart_id cart_cart_id CHAR(36) DEFAULT NULL COMMENT \'(DC2Type:uuid)\', CHANGE payed_at payed_at DATETIME DEFAULT NULL, CHANGE payed_token payed_token VARCHAR(255) DEFAULT NULL, CHANGE response response JSON DEFAULT NULL, CHANGE colissimo_code colissimo_code VARCHAR(255) DEFAULT NULL, CHANGE ip_client ip_client VARCHAR(255) DEFAULT NULL, CHANGE deleted_at deleted_at DATETIME DEFAULT NULL COMMENT \'(DC2Type:datetime_immutable)\'');
        $this->addSql('ALTER TABLE cart_cart_item CHANGE cart_cart_id cart_cart_id CHAR(36) DEFAULT NULL COMMENT \'(DC2Type:uuid)\', CHANGE product_variant_id product_variant_id CHAR(36) DEFAULT NULL COMMENT \'(DC2Type:uuid)\'');
        $this->addSql('ALTER TABLE cart_payment_method CHANGE deleted_at deleted_at DATETIME DEFAULT NULL COMMENT \'(DC2Type:datetime_immutable)\'');
        $this->addSql('ALTER TABLE cart_payment_method_translation CHANGE translatable_id translatable_id CHAR(36) DEFAULT NULL COMMENT \'(DC2Type:uuid)\', CHANGE configuration configuration JSON NOT NULL');
        $this->addSql('ALTER TABLE cart_promo CHANGE percent percent NUMERIC(3, 2) DEFAULT NULL, CHANGE percent_shipping_cost percent_shipping_cost NUMERIC(3, 2) DEFAULT NULL');
        $this->addSql('ALTER TABLE contact_contact CHANGE file_id file_id CHAR(36) DEFAULT NULL COMMENT \'(DC2Type:uuid)\', CHANGE image_id image_id CHAR(36) DEFAULT NULL COMMENT \'(DC2Type:uuid)\'');
        $this->addSql('ALTER TABLE contact_label CHANGE image_id image_id CHAR(36) DEFAULT NULL COMMENT \'(DC2Type:uuid)\'');
        $this->addSql('ALTER TABLE contact_label_translation CHANGE translatable_id translatable_id CHAR(36) DEFAULT NULL COMMENT \'(DC2Type:uuid)\'');
        $this->addSql('ALTER TABLE depot_category_translation CHANGE translatable_id translatable_id CHAR(36) DEFAULT NULL COMMENT \'(DC2Type:uuid)\'');
        $this->addSql('ALTER TABLE depot_depot CHANGE depot_category_id depot_category_id CHAR(36) DEFAULT NULL COMMENT \'(DC2Type:uuid)\', CHANGE deleted_at deleted_at DATETIME DEFAULT NULL COMMENT \'(DC2Type:datetime_immutable)\'');
        $this->addSql('ALTER TABLE depot_depot_translation CHANGE translatable_id translatable_id CHAR(36) DEFAULT NULL COMMENT \'(DC2Type:uuid)\'');
        $this->addSql('ALTER TABLE event_event CHANGE file_id file_id CHAR(36) DEFAULT NULL COMMENT \'(DC2Type:uuid)\', CHANGE end_at end_at DATETIME DEFAULT NULL');
        $this->addSql('ALTER TABLE event_event_image CHANGE event_id event_id CHAR(36) DEFAULT NULL COMMENT \'(DC2Type:uuid)\', CHANGE image_id image_id CHAR(36) DEFAULT NULL COMMENT \'(DC2Type:uuid)\'');
        $this->addSql('ALTER TABLE event_event_translation CHANGE translatable_id translatable_id CHAR(36) DEFAULT NULL COMMENT \'(DC2Type:uuid)\'');
        $this->addSql('ALTER TABLE gite_gite CHANGE video_id video_id CHAR(36) DEFAULT NULL COMMENT \'(DC2Type:uuid)\', CHANGE image_id image_id CHAR(36) DEFAULT NULL COMMENT \'(DC2Type:uuid)\', CHANGE file_id file_id CHAR(36) DEFAULT NULL COMMENT \'(DC2Type:uuid)\'');
        $this->addSql('ALTER TABLE gite_gite_image CHANGE gite_id gite_id CHAR(36) DEFAULT NULL COMMENT \'(DC2Type:uuid)\', CHANGE image_id image_id CHAR(36) DEFAULT NULL COMMENT \'(DC2Type:uuid)\'');
        $this->addSql('ALTER TABLE gite_gite_translation CHANGE translatable_id translatable_id CHAR(36) DEFAULT NULL COMMENT \'(DC2Type:uuid)\'');
        $this->addSql('ALTER TABLE gite_room CHANGE gite_id gite_id CHAR(36) DEFAULT NULL COMMENT \'(DC2Type:uuid)\', CHANGE video_id video_id CHAR(36) DEFAULT NULL COMMENT \'(DC2Type:uuid)\', CHANGE file_id file_id CHAR(36) DEFAULT NULL COMMENT \'(DC2Type:uuid)\'');
        $this->addSql('ALTER TABLE gite_room_image CHANGE room_id room_id CHAR(36) DEFAULT NULL COMMENT \'(DC2Type:uuid)\', CHANGE image_id image_id CHAR(36) DEFAULT NULL COMMENT \'(DC2Type:uuid)\'');
        $this->addSql('ALTER TABLE gite_room_translation CHANGE translatable_id translatable_id CHAR(36) DEFAULT NULL COMMENT \'(DC2Type:uuid)\'');
        $this->addSql('ALTER TABLE history_history CHANGE video_id video_id CHAR(36) DEFAULT NULL COMMENT \'(DC2Type:uuid)\', CHANGE file_id file_id CHAR(36) DEFAULT NULL COMMENT \'(DC2Type:uuid)\'');
        $this->addSql('ALTER TABLE history_history_image CHANGE history_id history_id CHAR(36) DEFAULT NULL COMMENT \'(DC2Type:uuid)\', CHANGE image_id image_id CHAR(36) DEFAULT NULL COMMENT \'(DC2Type:uuid)\'');
        $this->addSql('ALTER TABLE history_history_translation CHANGE translatable_id translatable_id CHAR(36) DEFAULT NULL COMMENT \'(DC2Type:uuid)\'');
        $this->addSql('ALTER TABLE library_library CHANGE image_id image_id CHAR(36) DEFAULT NULL COMMENT \'(DC2Type:uuid)\'');
        $this->addSql('ALTER TABLE library_library_translation CHANGE translatable_id translatable_id CHAR(36) DEFAULT NULL COMMENT \'(DC2Type:uuid)\'');
        $this->addSql('ALTER TABLE media_media CHANGE path path VARCHAR(255) DEFAULT NULL, CHANGE title title VARCHAR(255) DEFAULT NULL, CHANGE mime_type mime_type VARCHAR(255) DEFAULT NULL, CHANGE original_name original_name VARCHAR(255) DEFAULT NULL, CHANGE platform platform VARCHAR(255) DEFAULT NULL');
        $this->addSql('ALTER TABLE news_category_translation CHANGE translatable_id translatable_id CHAR(36) DEFAULT NULL COMMENT \'(DC2Type:uuid)\'');
        $this->addSql('ALTER TABLE news_news CHANGE news_category_id news_category_id CHAR(36) DEFAULT NULL COMMENT \'(DC2Type:uuid)\', CHANGE video_id video_id CHAR(36) DEFAULT NULL COMMENT \'(DC2Type:uuid)\', CHANGE file_id file_id CHAR(36) DEFAULT NULL COMMENT \'(DC2Type:uuid)\', CHANGE un_published_at un_published_at DATETIME DEFAULT NULL, CHANGE published_at published_at DATETIME DEFAULT NULL, CHANGE event_at event_at DATETIME DEFAULT NULL, CHANGE address address VARCHAR(255) DEFAULT NULL, CHANGE postal postal VARCHAR(255) DEFAULT NULL, CHANGE city city VARCHAR(255) DEFAULT NULL, CHANGE country country VARCHAR(255) DEFAULT NULL, CHANGE author author VARCHAR(255) DEFAULT NULL');
        $this->addSql('ALTER TABLE news_news_image CHANGE news_id news_id CHAR(36) DEFAULT NULL COMMENT \'(DC2Type:uuid)\', CHANGE image_id image_id CHAR(36) DEFAULT NULL COMMENT \'(DC2Type:uuid)\'');
        $this->addSql('ALTER TABLE news_news_translation CHANGE translatable_id translatable_id CHAR(36) DEFAULT NULL COMMENT \'(DC2Type:uuid)\'');
        $this->addSql('ALTER TABLE newsletter_newsletter CHANGE file_id file_id CHAR(36) DEFAULT NULL COMMENT \'(DC2Type:uuid)\'');
        $this->addSql('ALTER TABLE newsletter_newsletter_translation CHANGE translatable_id translatable_id CHAR(36) DEFAULT NULL COMMENT \'(DC2Type:uuid)\'');
        $this->addSql('ALTER TABLE payment_payment CHANGE payment_method_id payment_method_id CHAR(36) DEFAULT NULL COMMENT \'(DC2Type:uuid)\', CHANGE payed_at payed_at DATETIME DEFAULT NULL, CHANGE response response JSON DEFAULT NULL');
        $this->addSql('ALTER TABLE popup_popup CHANGE image_id image_id CHAR(36) DEFAULT NULL COMMENT \'(DC2Type:uuid)\', CHANGE un_published_at un_published_at DATETIME DEFAULT NULL, CHANGE published_at published_at DATETIME DEFAULT NULL');
        $this->addSql('ALTER TABLE popup_popup_translation CHANGE translatable_id translatable_id CHAR(36) DEFAULT NULL COMMENT \'(DC2Type:uuid)\'');
        $this->addSql('ALTER TABLE product_category_translation CHANGE translatable_id translatable_id CHAR(36) DEFAULT NULL COMMENT \'(DC2Type:uuid)\'');
        $this->addSql('ALTER TABLE product_degressive CHANGE package_percent package_percent NUMERIC(5, 3) DEFAULT NULL');
        $this->addSql('ALTER TABLE product_price CHANGE group_id group_id CHAR(36) DEFAULT NULL COMMENT \'(DC2Type:uuid)\', CHANGE variant_id variant_id CHAR(36) DEFAULT NULL COMMENT \'(DC2Type:uuid)\', CHANGE deleted_at deleted_at DATETIME DEFAULT NULL COMMENT \'(DC2Type:datetime_immutable)\'');
        $this->addSql('ALTER TABLE product_price_code CHANGE group_id group_id CHAR(36) DEFAULT NULL COMMENT \'(DC2Type:uuid)\', CHANGE deleted_at deleted_at DATETIME DEFAULT NULL COMMENT \'(DC2Type:datetime_immutable)\'');
        $this->addSql('ALTER TABLE product_price_group CHANGE deleted_at deleted_at DATETIME DEFAULT NULL COMMENT \'(DC2Type:datetime_immutable)\'');
        $this->addSql('ALTER TABLE product_product CHANGE product_category_id product_category_id CHAR(36) DEFAULT NULL COMMENT \'(DC2Type:uuid)\', CHANGE second_image_id second_image_id CHAR(36) DEFAULT NULL COMMENT \'(DC2Type:uuid)\', CHANGE background_image_id background_image_id CHAR(36) DEFAULT NULL COMMENT \'(DC2Type:uuid)\', CHANGE image_id image_id CHAR(36) DEFAULT NULL COMMENT \'(DC2Type:uuid)\', CHANGE file_id file_id CHAR(36) DEFAULT NULL COMMENT \'(DC2Type:uuid)\', CHANGE deleted_at deleted_at DATETIME DEFAULT NULL COMMENT \'(DC2Type:datetime_immutable)\'');
        $this->addSql('ALTER TABLE product_product_files CHANGE product_id product_id CHAR(36) DEFAULT NULL COMMENT \'(DC2Type:uuid)\', CHANGE file_id file_id CHAR(36) DEFAULT NULL COMMENT \'(DC2Type:uuid)\', CHANGE locale locale VARCHAR(255) DEFAULT NULL');
        $this->addSql('ALTER TABLE product_product_image CHANGE product_id product_id CHAR(36) DEFAULT NULL COMMENT \'(DC2Type:uuid)\', CHANGE image_id image_id CHAR(36) DEFAULT NULL COMMENT \'(DC2Type:uuid)\'');
        $this->addSql('ALTER TABLE product_product_translation CHANGE translatable_id translatable_id CHAR(36) DEFAULT NULL COMMENT \'(DC2Type:uuid)\', CHANGE assemblages assemblages JSON DEFAULT NULL, CHANGE winemaking winemaking JSON DEFAULT NULL');
        $this->addSql('ALTER TABLE product_type CHANGE volume volume NUMERIC(5, 2) DEFAULT NULL, CHANGE unity unity VARCHAR(255) DEFAULT NULL, CHANGE equivalency_degressive equivalency_degressive NUMERIC(4, 2) DEFAULT \'1\' NOT NULL');
        $this->addSql('ALTER TABLE product_type_translation CHANGE translatable_id translatable_id CHAR(36) DEFAULT NULL COMMENT \'(DC2Type:uuid)\'');
        $this->addSql('ALTER TABLE product_variant CHANGE product_id product_id CHAR(36) DEFAULT NULL COMMENT \'(DC2Type:uuid)\', CHANGE product_type_id product_type_id CHAR(36) DEFAULT NULL COMMENT \'(DC2Type:uuid)\', CHANGE deleted_at deleted_at DATETIME DEFAULT NULL COMMENT \'(DC2Type:datetime_immutable)\'');
        $this->addSql('ALTER TABLE season_season CHANGE video_id video_id CHAR(36) DEFAULT NULL COMMENT \'(DC2Type:uuid)\'');
        $this->addSql('ALTER TABLE season_season_image CHANGE season_id season_id CHAR(36) DEFAULT NULL COMMENT \'(DC2Type:uuid)\', CHANGE image_id image_id CHAR(36) DEFAULT NULL COMMENT \'(DC2Type:uuid)\'');
        $this->addSql('ALTER TABLE season_season_translation CHANGE translatable_id translatable_id CHAR(36) DEFAULT NULL COMMENT \'(DC2Type:uuid)\'');
        $this->addSql('ALTER TABLE shop_config_disable_country_translation CHANGE translatable_id translatable_id CHAR(36) DEFAULT NULL COMMENT \'(DC2Type:uuid)\', CHANGE description description VARCHAR(255) DEFAULT NULL');
        $this->addSql('ALTER TABLE shop_config_translation CHANGE translatable_id translatable_id CHAR(36) DEFAULT NULL COMMENT \'(DC2Type:uuid)\', CHANGE favorite_cat_name favorite_cat_name VARCHAR(255) DEFAULT NULL');
        $this->addSql('ALTER TABLE shop_delivery_method CHANGE delivery_category_id delivery_category_id CHAR(36) DEFAULT NULL COMMENT \'(DC2Type:uuid)\', CHANGE un_published_at un_published_at DATETIME DEFAULT NULL, CHANGE published_at published_at DATETIME DEFAULT NULL, CHANGE deleted_at deleted_at DATETIME DEFAULT NULL COMMENT \'(DC2Type:datetime_immutable)\'');
        $this->addSql('ALTER TABLE shop_delivery_method_category_translation CHANGE translatable_id translatable_id CHAR(36) DEFAULT NULL COMMENT \'(DC2Type:uuid)\', CHANGE min_view_text_open min_view_text_open VARCHAR(255) DEFAULT NULL, CHANGE min_view_text_close min_view_text_close VARCHAR(255) DEFAULT NULL');
        $this->addSql('ALTER TABLE shop_delivery_method_translation CHANGE translatable_id translatable_id CHAR(36) DEFAULT NULL COMMENT \'(DC2Type:uuid)\'');
        $this->addSql('ALTER TABLE shop_shipping_auto_sup CHANGE postal postal VARCHAR(255) DEFAULT NULL');
        $this->addSql('ALTER TABLE shop_shipping_config CHANGE file_sup_id file_sup_id CHAR(36) DEFAULT NULL COMMENT \'(DC2Type:uuid)\', CHANGE file_id file_id CHAR(36) DEFAULT NULL COMMENT \'(DC2Type:uuid)\', CHANGE margin_gazole_auto margin_gazole_auto NUMERIC(5, 4) DEFAULT NULL, CHANGE margin_auto margin_auto NUMERIC(5, 4) DEFAULT NULL, CHANGE margin_client_auto margin_client_auto NUMERIC(5, 4) DEFAULT NULL, CHANGE margin_manu margin_manu NUMERIC(5, 4) DEFAULT NULL, CHANGE margin_client_manu margin_client_manu NUMERIC(5, 4) DEFAULT NULL, CHANGE tva_manu tva_manu NUMERIC(5, 4) DEFAULT NULL, CHANGE margin_bank margin_bank NUMERIC(5, 4) DEFAULT NULL, CHANGE amount_percent_vdauto amount_percent_vdauto NUMERIC(5, 4) DEFAULT NULL, CHANGE carrier carrier VARCHAR(255) DEFAULT NULL');
        $this->addSql('ALTER TABLE shop_shipping_config_translation CHANGE translatable_id translatable_id CHAR(36) DEFAULT NULL COMMENT \'(DC2Type:uuid)\', CHANGE shipping_text shipping_text VARCHAR(255) DEFAULT NULL');
        $this->addSql('ALTER TABLE shop_shipping_county CHANGE zone_id zone_id CHAR(36) DEFAULT NULL COMMENT \'(DC2Type:uuid)\'');
        $this->addSql('ALTER TABLE shop_shipping_price CHANGE delivery_method_id delivery_method_id CHAR(36) DEFAULT NULL COMMENT \'(DC2Type:uuid)\', CHANGE private_marge_percent private_marge_percent NUMERIC(5, 4) DEFAULT NULL, CHANGE name_carrier name_carrier VARCHAR(255) DEFAULT NULL');
        $this->addSql('ALTER TABLE shop_shop_config CHANGE enable_countries_for_shop enable_countries_for_shop JSON DEFAULT \'[]\', CHANGE vacation_of vacation_of DATETIME DEFAULT NULL, CHANGE vacation_at vacation_at DATETIME DEFAULT NULL');
        $this->addSql('ALTER TABLE shop_shop_config_disable_country CHANGE config_id config_id CHAR(36) DEFAULT NULL COMMENT \'(DC2Type:uuid)\'');
        $this->addSql('ALTER TABLE shop_shop_config_multiple CHANGE config_id config_id CHAR(36) DEFAULT NULL COMMENT \'(DC2Type:uuid)\'');
        $this->addSql('ALTER TABLE socialnetwork_socialnetwork CHANGE configuration configuration JSON DEFAULT NULL, CHANGE token token VARCHAR(255) DEFAULT NULL, CHANGE token_at token_at DATETIME DEFAULT NULL, CHANGE data data JSON NOT NULL');
        $this->addSql('ALTER TABLE socialnetwork_socialnetworkNew CHANGE username username VARCHAR(255) DEFAULT NULL, CHANGE data data JSON NOT NULL');
        $this->addSql('ALTER TABLE user_user CHANGE roles roles JSON NOT NULL');
    }

    public function down(Schema $schema): void
    {
        // this down() migration is auto-generated, please modify it to your needs
        $this->addSql('ALTER TABLE award_award CHANGE image_id image_id CHAR(36) DEFAULT \'NULL\' COMMENT \'(DC2Type:uuid)\'');
        $this->addSql('ALTER TABLE award_award_translation CHANGE translatable_id translatable_id CHAR(36) DEFAULT \'NULL\' COMMENT \'(DC2Type:uuid)\'');
        $this->addSql('ALTER TABLE cart_cart CHANGE delivery_method_id delivery_method_id CHAR(36) DEFAULT \'NULL\' COMMENT \'(DC2Type:uuid)\', CHANGE invoice_address_id invoice_address_id CHAR(36) DEFAULT \'NULL\' COMMENT \'(DC2Type:uuid)\', CHANGE delivery_address_id delivery_address_id CHAR(36) DEFAULT \'NULL\' COMMENT \'(DC2Type:uuid)\', CHANGE shipping_name shipping_name VARCHAR(255) DEFAULT \'NULL\', CHANGE group_code group_code VARCHAR(255) DEFAULT \'NULL\', CHANGE delivery_method_json delivery_method_json LONGTEXT CHARACTER SET utf8mb4 DEFAULT NULL COLLATE `utf8mb4_bin`, CHANGE promo promo VARCHAR(255) DEFAULT \'NULL\', CHANGE promo_id promo_id CHAR(36) DEFAULT \'NULL\' COMMENT \'(DC2Type:uuid)\', CHANGE promo_value_percent promo_value_percent NUMERIC(3, 2) DEFAULT \'NULL\', CHANGE tax tax NUMERIC(3, 2) DEFAULT \'NULL\'');
        $this->addSql('ALTER TABLE cart_cart_checkout CHANGE payment_method_id payment_method_id CHAR(36) DEFAULT \'NULL\' COMMENT \'(DC2Type:uuid)\', CHANGE cart_cart_id cart_cart_id CHAR(36) DEFAULT \'NULL\' COMMENT \'(DC2Type:uuid)\', CHANGE payed_at payed_at DATETIME DEFAULT \'NULL\', CHANGE payed_token payed_token VARCHAR(255) DEFAULT \'NULL\', CHANGE response response LONGTEXT CHARACTER SET utf8mb4 DEFAULT NULL COLLATE `utf8mb4_bin`, CHANGE colissimo_code colissimo_code VARCHAR(255) DEFAULT \'NULL\', CHANGE ip_client ip_client VARCHAR(255) DEFAULT \'NULL\', CHANGE deleted_at deleted_at DATETIME DEFAULT \'NULL\' COMMENT \'(DC2Type:datetime_immutable)\'');
        $this->addSql('ALTER TABLE cart_cart_item CHANGE cart_cart_id cart_cart_id CHAR(36) DEFAULT \'NULL\' COMMENT \'(DC2Type:uuid)\', CHANGE product_variant_id product_variant_id CHAR(36) DEFAULT \'NULL\' COMMENT \'(DC2Type:uuid)\'');
        $this->addSql('ALTER TABLE cart_payment_method CHANGE deleted_at deleted_at DATETIME DEFAULT \'NULL\' COMMENT \'(DC2Type:datetime_immutable)\'');
        $this->addSql('ALTER TABLE cart_payment_method_translation CHANGE translatable_id translatable_id CHAR(36) DEFAULT \'NULL\' COMMENT \'(DC2Type:uuid)\', CHANGE configuration configuration LONGTEXT CHARACTER SET utf8mb4 NOT NULL COLLATE `utf8mb4_bin`');
        $this->addSql('ALTER TABLE cart_promo CHANGE percent percent NUMERIC(3, 2) DEFAULT \'NULL\', CHANGE percent_shipping_cost percent_shipping_cost NUMERIC(3, 2) DEFAULT \'NULL\'');
        $this->addSql('ALTER TABLE contact_contact CHANGE file_id file_id CHAR(36) DEFAULT \'NULL\' COMMENT \'(DC2Type:uuid)\', CHANGE image_id image_id CHAR(36) DEFAULT \'NULL\' COMMENT \'(DC2Type:uuid)\'');
        $this->addSql('ALTER TABLE contact_label CHANGE image_id image_id CHAR(36) DEFAULT \'NULL\' COMMENT \'(DC2Type:uuid)\'');
        $this->addSql('ALTER TABLE contact_label_translation CHANGE translatable_id translatable_id CHAR(36) DEFAULT \'NULL\' COMMENT \'(DC2Type:uuid)\'');
        $this->addSql('ALTER TABLE depot_category_translation CHANGE translatable_id translatable_id CHAR(36) DEFAULT \'NULL\' COMMENT \'(DC2Type:uuid)\'');
        $this->addSql('ALTER TABLE depot_depot CHANGE depot_category_id depot_category_id CHAR(36) DEFAULT \'NULL\' COMMENT \'(DC2Type:uuid)\', CHANGE deleted_at deleted_at DATETIME DEFAULT \'NULL\' COMMENT \'(DC2Type:datetime_immutable)\'');
        $this->addSql('ALTER TABLE depot_depot_translation CHANGE translatable_id translatable_id CHAR(36) DEFAULT \'NULL\' COMMENT \'(DC2Type:uuid)\'');
        $this->addSql('ALTER TABLE event_event CHANGE file_id file_id CHAR(36) DEFAULT \'NULL\' COMMENT \'(DC2Type:uuid)\', CHANGE end_at end_at DATETIME DEFAULT \'NULL\'');
        $this->addSql('ALTER TABLE event_event_image CHANGE event_id event_id CHAR(36) DEFAULT \'NULL\' COMMENT \'(DC2Type:uuid)\', CHANGE image_id image_id CHAR(36) DEFAULT \'NULL\' COMMENT \'(DC2Type:uuid)\'');
        $this->addSql('ALTER TABLE event_event_translation CHANGE translatable_id translatable_id CHAR(36) DEFAULT \'NULL\' COMMENT \'(DC2Type:uuid)\'');
        $this->addSql('ALTER TABLE gite_gite CHANGE video_id video_id CHAR(36) DEFAULT \'NULL\' COMMENT \'(DC2Type:uuid)\', CHANGE image_id image_id CHAR(36) DEFAULT \'NULL\' COMMENT \'(DC2Type:uuid)\', CHANGE file_id file_id CHAR(36) DEFAULT \'NULL\' COMMENT \'(DC2Type:uuid)\'');
        $this->addSql('ALTER TABLE gite_gite_image CHANGE gite_id gite_id CHAR(36) DEFAULT \'NULL\' COMMENT \'(DC2Type:uuid)\', CHANGE image_id image_id CHAR(36) DEFAULT \'NULL\' COMMENT \'(DC2Type:uuid)\'');
        $this->addSql('ALTER TABLE gite_gite_translation CHANGE translatable_id translatable_id CHAR(36) DEFAULT \'NULL\' COMMENT \'(DC2Type:uuid)\'');
        $this->addSql('ALTER TABLE gite_room CHANGE gite_id gite_id CHAR(36) DEFAULT \'NULL\' COMMENT \'(DC2Type:uuid)\', CHANGE video_id video_id CHAR(36) DEFAULT \'NULL\' COMMENT \'(DC2Type:uuid)\', CHANGE file_id file_id CHAR(36) DEFAULT \'NULL\' COMMENT \'(DC2Type:uuid)\'');
        $this->addSql('ALTER TABLE gite_room_image CHANGE room_id room_id CHAR(36) DEFAULT \'NULL\' COMMENT \'(DC2Type:uuid)\', CHANGE image_id image_id CHAR(36) DEFAULT \'NULL\' COMMENT \'(DC2Type:uuid)\'');
        $this->addSql('ALTER TABLE gite_room_translation CHANGE translatable_id translatable_id CHAR(36) DEFAULT \'NULL\' COMMENT \'(DC2Type:uuid)\'');
        $this->addSql('ALTER TABLE history_history CHANGE video_id video_id CHAR(36) DEFAULT \'NULL\' COMMENT \'(DC2Type:uuid)\', CHANGE file_id file_id CHAR(36) DEFAULT \'NULL\' COMMENT \'(DC2Type:uuid)\'');
        $this->addSql('ALTER TABLE history_history_image CHANGE history_id history_id CHAR(36) DEFAULT \'NULL\' COMMENT \'(DC2Type:uuid)\', CHANGE image_id image_id CHAR(36) DEFAULT \'NULL\' COMMENT \'(DC2Type:uuid)\'');
        $this->addSql('ALTER TABLE history_history_translation CHANGE translatable_id translatable_id CHAR(36) DEFAULT \'NULL\' COMMENT \'(DC2Type:uuid)\'');
        $this->addSql('ALTER TABLE library_library CHANGE image_id image_id CHAR(36) DEFAULT \'NULL\' COMMENT \'(DC2Type:uuid)\'');
        $this->addSql('ALTER TABLE library_library_translation CHANGE translatable_id translatable_id CHAR(36) DEFAULT \'NULL\' COMMENT \'(DC2Type:uuid)\'');
        $this->addSql('ALTER TABLE media_media CHANGE path path VARCHAR(255) DEFAULT \'NULL\', CHANGE title title VARCHAR(255) DEFAULT \'NULL\', CHANGE mime_type mime_type VARCHAR(255) DEFAULT \'NULL\', CHANGE original_name original_name VARCHAR(255) DEFAULT \'NULL\', CHANGE platform platform VARCHAR(255) DEFAULT \'NULL\'');
        $this->addSql('ALTER TABLE news_category_translation CHANGE translatable_id translatable_id CHAR(36) DEFAULT \'NULL\' COMMENT \'(DC2Type:uuid)\'');
        $this->addSql('ALTER TABLE news_news CHANGE news_category_id news_category_id CHAR(36) DEFAULT \'NULL\' COMMENT \'(DC2Type:uuid)\', CHANGE video_id video_id CHAR(36) DEFAULT \'NULL\' COMMENT \'(DC2Type:uuid)\', CHANGE file_id file_id CHAR(36) DEFAULT \'NULL\' COMMENT \'(DC2Type:uuid)\', CHANGE un_published_at un_published_at DATETIME DEFAULT \'NULL\', CHANGE published_at published_at DATETIME DEFAULT \'NULL\', CHANGE event_at event_at DATETIME DEFAULT \'NULL\', CHANGE address address VARCHAR(255) DEFAULT \'NULL\', CHANGE postal postal VARCHAR(255) DEFAULT \'NULL\', CHANGE city city VARCHAR(255) DEFAULT \'NULL\', CHANGE country country VARCHAR(255) DEFAULT \'NULL\', CHANGE author author VARCHAR(255) DEFAULT \'NULL\'');
        $this->addSql('ALTER TABLE news_news_image CHANGE news_id news_id CHAR(36) DEFAULT \'NULL\' COMMENT \'(DC2Type:uuid)\', CHANGE image_id image_id CHAR(36) DEFAULT \'NULL\' COMMENT \'(DC2Type:uuid)\'');
        $this->addSql('ALTER TABLE news_news_translation CHANGE translatable_id translatable_id CHAR(36) DEFAULT \'NULL\' COMMENT \'(DC2Type:uuid)\'');
        $this->addSql('ALTER TABLE newsletter_newsletter CHANGE file_id file_id CHAR(36) DEFAULT \'NULL\' COMMENT \'(DC2Type:uuid)\'');
        $this->addSql('ALTER TABLE newsletter_newsletter_translation CHANGE translatable_id translatable_id CHAR(36) DEFAULT \'NULL\' COMMENT \'(DC2Type:uuid)\'');
        $this->addSql('ALTER TABLE payment_payment CHANGE payment_method_id payment_method_id CHAR(36) DEFAULT \'NULL\' COMMENT \'(DC2Type:uuid)\', CHANGE payed_at payed_at DATETIME DEFAULT \'NULL\', CHANGE response response LONGTEXT CHARACTER SET utf8mb4 DEFAULT NULL COLLATE `utf8mb4_bin`');
        $this->addSql('ALTER TABLE popup_popup CHANGE image_id image_id CHAR(36) DEFAULT \'NULL\' COMMENT \'(DC2Type:uuid)\', CHANGE un_published_at un_published_at DATETIME DEFAULT \'NULL\', CHANGE published_at published_at DATETIME DEFAULT \'NULL\'');
        $this->addSql('ALTER TABLE popup_popup_translation CHANGE translatable_id translatable_id CHAR(36) DEFAULT \'NULL\' COMMENT \'(DC2Type:uuid)\'');
        $this->addSql('ALTER TABLE product_category_translation CHANGE translatable_id translatable_id CHAR(36) DEFAULT \'NULL\' COMMENT \'(DC2Type:uuid)\'');
        $this->addSql('ALTER TABLE product_degressive CHANGE package_percent package_percent NUMERIC(5, 3) DEFAULT \'NULL\'');
        $this->addSql('ALTER TABLE product_price CHANGE group_id group_id CHAR(36) DEFAULT \'NULL\' COMMENT \'(DC2Type:uuid)\', CHANGE variant_id variant_id CHAR(36) DEFAULT \'NULL\' COMMENT \'(DC2Type:uuid)\', CHANGE deleted_at deleted_at DATETIME DEFAULT \'NULL\' COMMENT \'(DC2Type:datetime_immutable)\'');
        $this->addSql('ALTER TABLE product_price_code CHANGE group_id group_id CHAR(36) DEFAULT \'NULL\' COMMENT \'(DC2Type:uuid)\', CHANGE deleted_at deleted_at DATETIME DEFAULT \'NULL\' COMMENT \'(DC2Type:datetime_immutable)\'');
        $this->addSql('ALTER TABLE product_price_group CHANGE deleted_at deleted_at DATETIME DEFAULT \'NULL\' COMMENT \'(DC2Type:datetime_immutable)\'');
        $this->addSql('ALTER TABLE product_product CHANGE product_category_id product_category_id CHAR(36) DEFAULT \'NULL\' COMMENT \'(DC2Type:uuid)\', CHANGE second_image_id second_image_id CHAR(36) DEFAULT \'NULL\' COMMENT \'(DC2Type:uuid)\', CHANGE background_image_id background_image_id CHAR(36) DEFAULT \'NULL\' COMMENT \'(DC2Type:uuid)\', CHANGE image_id image_id CHAR(36) DEFAULT \'NULL\' COMMENT \'(DC2Type:uuid)\', CHANGE file_id file_id CHAR(36) DEFAULT \'NULL\' COMMENT \'(DC2Type:uuid)\', CHANGE deleted_at deleted_at DATETIME DEFAULT \'NULL\' COMMENT \'(DC2Type:datetime_immutable)\'');
        $this->addSql('ALTER TABLE product_product_files CHANGE product_id product_id CHAR(36) DEFAULT \'NULL\' COMMENT \'(DC2Type:uuid)\', CHANGE file_id file_id CHAR(36) DEFAULT \'NULL\' COMMENT \'(DC2Type:uuid)\', CHANGE locale locale VARCHAR(255) DEFAULT \'NULL\'');
        $this->addSql('ALTER TABLE product_product_image CHANGE product_id product_id CHAR(36) DEFAULT \'NULL\' COMMENT \'(DC2Type:uuid)\', CHANGE image_id image_id CHAR(36) DEFAULT \'NULL\' COMMENT \'(DC2Type:uuid)\'');
        $this->addSql('ALTER TABLE product_product_translation CHANGE translatable_id translatable_id CHAR(36) DEFAULT \'NULL\' COMMENT \'(DC2Type:uuid)\', CHANGE assemblages assemblages LONGTEXT CHARACTER SET utf8mb4 DEFAULT NULL COLLATE `utf8mb4_bin`, CHANGE winemaking winemaking LONGTEXT CHARACTER SET utf8mb4 DEFAULT NULL COLLATE `utf8mb4_bin`');
        $this->addSql('ALTER TABLE product_type CHANGE volume volume NUMERIC(5, 2) DEFAULT \'NULL\', CHANGE unity unity VARCHAR(255) DEFAULT \'NULL\', CHANGE equivalency_degressive equivalency_degressive NUMERIC(4, 2) DEFAULT \'1.00\' NOT NULL');
        $this->addSql('ALTER TABLE product_type_translation CHANGE translatable_id translatable_id CHAR(36) DEFAULT \'NULL\' COMMENT \'(DC2Type:uuid)\'');
        $this->addSql('ALTER TABLE product_variant CHANGE product_id product_id CHAR(36) DEFAULT \'NULL\' COMMENT \'(DC2Type:uuid)\', CHANGE product_type_id product_type_id CHAR(36) DEFAULT \'NULL\' COMMENT \'(DC2Type:uuid)\', CHANGE deleted_at deleted_at DATETIME DEFAULT \'NULL\' COMMENT \'(DC2Type:datetime_immutable)\'');
        $this->addSql('ALTER TABLE season_season CHANGE video_id video_id CHAR(36) DEFAULT \'NULL\' COMMENT \'(DC2Type:uuid)\'');
        $this->addSql('ALTER TABLE season_season_image CHANGE season_id season_id CHAR(36) DEFAULT \'NULL\' COMMENT \'(DC2Type:uuid)\', CHANGE image_id image_id CHAR(36) DEFAULT \'NULL\' COMMENT \'(DC2Type:uuid)\'');
        $this->addSql('ALTER TABLE season_season_translation CHANGE translatable_id translatable_id CHAR(36) DEFAULT \'NULL\' COMMENT \'(DC2Type:uuid)\'');
        $this->addSql('ALTER TABLE shop_config_disable_country_translation CHANGE translatable_id translatable_id CHAR(36) DEFAULT \'NULL\' COMMENT \'(DC2Type:uuid)\', CHANGE description description VARCHAR(255) DEFAULT \'NULL\'');
        $this->addSql('ALTER TABLE shop_config_translation CHANGE translatable_id translatable_id CHAR(36) DEFAULT \'NULL\' COMMENT \'(DC2Type:uuid)\', CHANGE favorite_cat_name favorite_cat_name VARCHAR(255) DEFAULT \'NULL\'');
        $this->addSql('ALTER TABLE shop_delivery_method CHANGE delivery_category_id delivery_category_id CHAR(36) DEFAULT \'NULL\' COMMENT \'(DC2Type:uuid)\', CHANGE un_published_at un_published_at DATETIME DEFAULT \'NULL\', CHANGE published_at published_at DATETIME DEFAULT \'NULL\', CHANGE deleted_at deleted_at DATETIME DEFAULT \'NULL\' COMMENT \'(DC2Type:datetime_immutable)\'');
        $this->addSql('ALTER TABLE shop_delivery_method_category_translation CHANGE translatable_id translatable_id CHAR(36) DEFAULT \'NULL\' COMMENT \'(DC2Type:uuid)\', CHANGE min_view_text_open min_view_text_open VARCHAR(255) DEFAULT \'NULL\', CHANGE min_view_text_close min_view_text_close VARCHAR(255) DEFAULT \'NULL\'');
        $this->addSql('ALTER TABLE shop_delivery_method_translation CHANGE translatable_id translatable_id CHAR(36) DEFAULT \'NULL\' COMMENT \'(DC2Type:uuid)\'');
        $this->addSql('ALTER TABLE shop_shipping_auto_sup CHANGE postal postal VARCHAR(255) DEFAULT \'NULL\'');
        $this->addSql('ALTER TABLE shop_shipping_config CHANGE file_sup_id file_sup_id CHAR(36) DEFAULT \'NULL\' COMMENT \'(DC2Type:uuid)\', CHANGE file_id file_id CHAR(36) DEFAULT \'NULL\' COMMENT \'(DC2Type:uuid)\', CHANGE margin_gazole_auto margin_gazole_auto NUMERIC(5, 4) DEFAULT \'NULL\', CHANGE margin_auto margin_auto NUMERIC(5, 4) DEFAULT \'NULL\', CHANGE margin_client_auto margin_client_auto NUMERIC(5, 4) DEFAULT \'NULL\', CHANGE margin_manu margin_manu NUMERIC(5, 4) DEFAULT \'NULL\', CHANGE margin_client_manu margin_client_manu NUMERIC(5, 4) DEFAULT \'NULL\', CHANGE tva_manu tva_manu NUMERIC(5, 4) DEFAULT \'NULL\', CHANGE margin_bank margin_bank NUMERIC(5, 4) DEFAULT \'NULL\', CHANGE amount_percent_vdauto amount_percent_vdauto NUMERIC(5, 4) DEFAULT \'NULL\', CHANGE carrier carrier VARCHAR(255) DEFAULT \'NULL\'');
        $this->addSql('ALTER TABLE shop_shipping_config_translation CHANGE translatable_id translatable_id CHAR(36) DEFAULT \'NULL\' COMMENT \'(DC2Type:uuid)\', CHANGE shipping_text shipping_text VARCHAR(255) DEFAULT \'NULL\'');
        $this->addSql('ALTER TABLE shop_shipping_county CHANGE zone_id zone_id CHAR(36) DEFAULT \'NULL\' COMMENT \'(DC2Type:uuid)\'');
        $this->addSql('ALTER TABLE shop_shipping_price CHANGE delivery_method_id delivery_method_id CHAR(36) DEFAULT \'NULL\' COMMENT \'(DC2Type:uuid)\', CHANGE private_marge_percent private_marge_percent NUMERIC(5, 4) DEFAULT \'NULL\', CHANGE name_carrier name_carrier VARCHAR(255) DEFAULT \'NULL\'');
        $this->addSql('ALTER TABLE shop_shop_config CHANGE enable_countries_for_shop enable_countries_for_shop LONGTEXT CHARACTER SET utf8mb4 DEFAULT NULL COLLATE `utf8mb4_bin`, CHANGE vacation_of vacation_of DATETIME DEFAULT \'NULL\', CHANGE vacation_at vacation_at DATETIME DEFAULT \'NULL\'');
        $this->addSql('ALTER TABLE shop_shop_config_disable_country CHANGE config_id config_id CHAR(36) DEFAULT \'NULL\' COMMENT \'(DC2Type:uuid)\'');
        $this->addSql('ALTER TABLE shop_shop_config_multiple CHANGE config_id config_id CHAR(36) DEFAULT \'NULL\' COMMENT \'(DC2Type:uuid)\'');
        $this->addSql('ALTER TABLE socialnetwork_socialnetwork CHANGE configuration configuration LONGTEXT CHARACTER SET utf8mb4 DEFAULT NULL COLLATE `utf8mb4_bin`, CHANGE token token VARCHAR(255) DEFAULT \'NULL\', CHANGE token_at token_at DATETIME DEFAULT \'NULL\', CHANGE data data LONGTEXT CHARACTER SET utf8mb4 NOT NULL COLLATE `utf8mb4_bin`');
        $this->addSql('ALTER TABLE socialnetwork_socialnetworkNew CHANGE username username VARCHAR(255) DEFAULT \'NULL\', CHANGE data data LONGTEXT CHARACTER SET utf8mb4 NOT NULL COLLATE `utf8mb4_bin`');
        $this->addSql('ALTER TABLE user_user CHANGE roles roles LONGTEXT CHARACTER SET utf8mb4 NOT NULL COLLATE `utf8mb4_bin`');
    }
}
