<?php
/**
 * @author Colinet Julien
 */

namespace CpCreation\VitiCore\Bridge\Symfony\Bundle\Form\Admin;

use Symfony\Component\Form\AbstractType;
use Symfony\Component\Form\Extension\Core\Type\TextType;
use Symfony\Component\Form\FormBuilderInterface;
use Symfony\Component\OptionsResolver\OptionsResolver;

class GiftCheckType extends AbstractType
{
    public function buildForm(FormBuilderInterface $builder, array $options){
        $builder->add('token',TextType::class,[
            'required' => true,
            'label' => 'Clé de validation',
            'label_attr' => [
                'class' => 'gift-form-label'
            ]
        ]);
    }

    public function configureOptions(OptionsResolver $resolver)
    {
        $resolver->setDefaults(
            [
                'data_class' => null,
                'title'      => false,
                'required'   => false,
            ]
        );
    }
}