<?php
/**
 * @author Colinet Julien
 */

namespace CpCreation\VitiCore\Behavior;

interface HasSortable
{

    /**
     * @return int | null
     */
    public function getPosition(): ?int;

    /**
     * @param int $position
     */

    public function setPosition(?int $position);
}
