{% extends '@CpCreationVitiCore/admin/base.html.twig' %}

{% block content %}
   <h1 class="page-header">Commande {{ cart.token }} - {{ cart.invoiceAddress.lastname }} {{ cart.invoiceAddress.firstname}}</h1>
      <div class="panel panel-default">
         <div class="panel-heading">
            <a href="{{path("admin_order")}}"><button type="button" class="btn btn-danger btn-rounded">Retour</button></a>
            <div class="clearfix"></div>
         </div>
      </div>
    {{ include('pdf/order.html.twig',{ contact: contact, cart: cart}) }}
      <div class="panel panel-default">
         <div class="panel-heading">
            <a href="{{path("admin_order")}}"><button type="button" class="btn btn-danger btn-rounded">Annuler</button></a>
         </div>
      </div>

{% endblock %}