<?php
/**
 * @author Colinet Julien
 */

namespace CpCreation\VitiCore\Bridge\Symfony\Bundle\Client;

use GuzzleHttp\Client;

class ConnectCpCreationClient extends Client
{
    public function __construct(Client $client) {

        parent::__construct($client->getConfig());
    }
}