<?php
/**
 * @author Colinet Julien
 */

namespace CpCreation\VitiCore\Cart\Model\Payment;


class SogeCommerce
{
    /**
     * @var string
     */
    private $name;

    /**
     * @var string
     */
    private $mode;

    /**
     * @var string
     */
    private $site_id;

    /**
     * @var string
     */
    private $key;

    /**
     * @var string
     */
    private $hmacAlgo;

    /**
     * @return string
     */
    public function getHmacAlgo(): ?string
    {
        return $this->hmacAlgo;
    }

    /**
     * @param string $hmacAlgo
     */
    public function setHmacAlgo(string $hmacAlgo): void
    {
        $this->hmacAlgo = $hmacAlgo;
    }

    /**
     * @return string
     */
    public function getName(): ?string
    {
        return $this->name;
    }

    /**
     * @param string $name
     */
    public function setName(string $name): void
    {
        $this->name = $name;
    }

    /**
     * @return string
     */
    public function getMode(): ?string
    {
        return $this->mode;
    }

    /**
     * @param string $mode
     */
    public function setMode(string $mode): void
    {
        $this->mode = $mode;
    }

    /**
     * @return string
     */
    public function getSiteId(): ?string
    {
        return $this->site_id;
    }

    /**
     * @param string $site_id
     */
    public function setSiteId(string $site_id): void
    {
        $this->site_id = $site_id;
    }

    /**
     * @return string
     */
    public function getKey(): ?string
    {
        return $this->key;
    }

    /**
     * @param string $key
     */
    public function setKey(string $key): void
    {
        $this->key = $key;
    }
}
